@@ -92,32 +92,21 @@ class GeometryFieldRenderer(FieldRenderer):
     def deserialize(self):
         """Turns the user input into a GeoAlchemy geometry, which
         can be stored in the database.
-        
-        If necessary the geometry is reprojected by making a database query. 
         """
         form_value = self.params.getone(self.name)
         
         if form_value is not None and form_value.strip() != '':
-            options = self.__get_options()
-            geom_srid = self.field.type.srid
-            map_srid = options.get('map_srid', geom_srid)
-            wkt_elt = WKTSpatialElement(form_value, srid=map_srid)
-            
-            if geom_srid != map_srid:
-                # if the map uses a different CRS, we have to reproject
-                query = functions.wkt(functions.transform(wkt_elt, geom_srid))
-                session = self.field.parent.session
-                return session.scalar(query)
+            return WKTSpatialElement(
+                form_value,
+                srid=self.__get_options().get('map_srid', self.field.type.srid))
 
-            return wkt_elt
-                
         return None
     
     def __render_map(self, read_only):
         options = self.__get_options()
         geometry_type = self.__get_type_information()
         
-        if len(self.errors) > 0:
+        if len(self.field.errors) > 0:
             # if re-displaying a form with errors, get the WKT string
             # from the form submission
             wkt = self.params.getone(self.name)
@@ -154,7 +143,7 @@ class GeometryFieldRenderer(FieldRenderer):
             the 'map.mako' template file is in the same folder as the other FormAlchemy template files.
             This is the case when used inside a Pylons app."""
             return config.engine.render('map', **template_args)
-        except (TemplateLookupException, AttributeError):
+        except (TemplateLookupException, AttributeError, ValueError):
             # otherwise render the default template using an own template engine
             map_template = self.get_templates().get_template('map.mako')
             return map_template.render(**template_args)
